Hubbub - crowdfunding for education and social good
Description: crowdfunding for education and social good

Everything you need to power your fundraising.

# Branded Crowdfunding

Hubbub's Pro-Site is a fully featured own-branded crowdfunding platform that has been used with great success by universities and non-profits worldwide. At the University of York, crowdfunding using YuStart - the name for their Pro-Site - led to an increase of 33% in total donor numbers in just one year.

- Find out more
- View case study

# Enrich Social Analytics

Enrich(TM) can automatically clean and analyse your existing supporter, donor, staff and student databases, social media connections and other third-party sources to identify individuals on social media and extract information about their influence, interests, qualifications, job title and location. The data allows you to make a step change in many different areas of fundraising and alumni relations - for example, segmenting communications, locating lost alumni, identify potential high net worth donors, and even forewarning you of supporters who change addresses.

Find out more

# Giving Days

Giving Days empower others within your community to become your fundraisers and ambassadors. By leveraging Hubbub's social analytics technology, and combining it with our fundraising products, you can identify ambassadors, create and suggest appropriate content and messaging, distribute this to your new found ambassadors, track their influence and donations from their network, and raise significant sums of money in very short periods of time. We provide both technology and consultancy services to ensure you generate the most income and stimulate exciting new engagement.

Find out more